@@ -1,7 +1,7 @@
 #' Create Batch
 #'
 #' Create a new batch. 
-#' 
+#'
 #' @param batch_name name of the batch; Required; character
 #' @param \dots Additional arguments passed to \code{\link{captr_POST}}.
 #'  
@@ -10,20 +10,16 @@
 #' @export
 #' @references \url{https://shreddr.captricity.com/developer/api-reference/#v1-batch}
 #' @examples \dontrun{
-#' create_batch(batch_name="name_of_batch")
+#' create_batch(batch_name = "name_of_batch")
 #' }
 
 create_batch <- function(batch_name = NULL, ...) {
-    
-    captr_CHECKAUTH()
-  	
-  	if (is.null(batch_name) | identical(batch_name, "")) stop("Specify a valid batch_name.") 
 
-  	query <- list(name = batch_name)
+  if (is.null(batch_name) | identical(batch_name, "")) stop("Specify a valid batch_name.")
 
-	res <- captr_POST(path="batch/", query, ...)
+  query <-  list(name = batch_name)
 
-    invisible(res)
+  res <-  captr_POST(path = "batch/", query, ...)
+
+  res
 }
-
-
