@@ -2,9 +2,10 @@
 #' 
 #' To digitize documents, create a template using the Captricity Web UI at \url{https://shreddr.captricity.com/job/} 
 #' The template tells Captricity which data to get from where in the document.
-#' Get the template id of the template
 #' 
-#' @param \dots Additional arguments passed to \code{\link{captr_POST}}.
+#' Get the template ids of all the documents
+#' 
+#' @param \dots Additional arguments passed to \code{\link{captr_GET}}.
 #' 
 #' @return named list
 #' 
@@ -16,12 +17,9 @@
 #' }
 
 get_template_id <- function(...) {
-    
-    captr_CHECKAUTH()
- 
- 	res <- captr_POST(path="document/", ...)
 
-    return(invisible(res))
+  res <- captr_GET(path = "document/", ...)
+
+  res
 
 }
-
