@@ -11,15 +11,11 @@
 #' list_batch_files("batch_id")
 #' }
 
-list_batch_files <- function(batch_id="", ...) {
-    
-    captr_CHECKAUTH()
- 
-    if ( is.null(batch_id) | identical(batch_id, "")) stop("Provide a Valid Batch ID.")
+list_batch_files <- function(batch_id = "", ...) {
 
-    res <- captr_GET(paste0("batch/", batch_id, "/batch-file"), ...)
+  if ( is.null(batch_id) | identical(batch_id, "")) stop("Provide a Valid Batch ID.")
 
-    return(invisible(res))
+  res <- captr_GET(paste0("batch/", batch_id, "/batch-file"), ...)
 
+  res
 }
-
