@@ -2,20 +2,21 @@
 #'
 #' A list of jobs owned by the calling account. 
 #' 
+#' @param \dots Additional arguments passed to \code{\link{captr_GET}}.
+#' 
 #' @export
 #' @references \url{https://shreddr.captricity.com/developer/api-reference/#v1-jobs}
+#' 
 #' @examples \dontrun{
 #' list_jobs()
 #' }
 
-list_jobs <- function() {
-    
-    res <- captr_GET("job/", NULL)
+list_jobs <- function(...) {
 
-    cat("No. of jobs:", nrow(res), "\n")
+  res <- captr_GET("job/", ...)
 
-    return(invisible(res))
+  cat("No. of jobs:", nrow(res), "\n")
+
+  res
 
 }
-
- 
